Index: code/branches/cpp11_v2/src/libraries/util/Clipboard.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/Clipboard.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/Clipboard.cc	(revision 10765)
@@ -93,5 +93,5 @@
             {
                 HANDLE hData = GetClipboardData(CF_TEXT);
-                if (hData == NULL)
+                if (hData == nullptr)
                     return "";
                 std::string output(static_cast<char*>(GlobalLock(hData)));
Index: code/branches/cpp11_v2/src/libraries/util/DestructionHelper.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/DestructionHelper.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/DestructionHelper.h	(revision 10765)
@@ -36,5 +36,5 @@
     /** Deletes an object and resets the pointer
     @param object
-        Pointer to an object. Handing over NULL is safe.
+        Pointer to an object. Handing over nullptr is safe.
     */
     template <class T>
@@ -42,5 +42,5 @@
     {
         delete *object;
-        *object = NULL;
+        *object = nullptr;
     }
 
Index: code/branches/cpp11_v2/src/libraries/util/SharedPtr.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/SharedPtr.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/SharedPtr.h	(revision 10765)
@@ -215,5 +215,5 @@
 
         public:
-            /// Default constructor, the pointer is set to NULL.
+            /// Default constructor, the pointer is set to nullptr.
             inline SharedPtr() : pointer_(0), counter_(0)
             {
@@ -310,5 +310,5 @@
             }
 
-            /// Returns true if the pointer is not NULL.
+            /// Returns true if the pointer is not nullptr.
             inline operator bool() const
             {
Index: code/branches/cpp11_v2/src/libraries/util/SignalHandler.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/SignalHandler.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/SignalHandler.h	(revision 10765)
@@ -113,5 +113,5 @@
             void doCatch(const std::string& appName, const std::string& filename);
 
-            static std::string getStackTrace(PEXCEPTION_POINTERS pExceptionInfo = NULL);
+            static std::string getStackTrace(PEXCEPTION_POINTERS pExceptionInfo = nullptr);
             static std::string getExceptionType(PEXCEPTION_POINTERS pExceptionInfo);
 
Index: code/branches/cpp11_v2/src/libraries/util/Singleton.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/Singleton.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/Singleton.h	(revision 10765)
@@ -66,5 +66,5 @@
     And don't forget to initialize the static singleton pointer in the source (*.cc) %file:
     @code
-    TestSingleton* TestSingleton::singletonPtr_s = NULL;
+    TestSingleton* TestSingleton::singletonPtr_s = nullptr;
     @endcode
 
@@ -118,5 +118,5 @@
         static T& getInstance()
         {
-            OrxVerify(T::singletonPtr_s != NULL, "T=" << typeid(T).name());
+            OrxVerify(T::singletonPtr_s != nullptr, "T=" << typeid(T).name());
             return *T::singletonPtr_s;
         }
@@ -125,5 +125,5 @@
         static bool exists()
         {
-            return (T::singletonPtr_s != NULL);
+            return (T::singletonPtr_s != nullptr);
         }
 
@@ -132,5 +132,5 @@
         Singleton()
         {
-            OrxVerify(T::singletonPtr_s == NULL, "T=" << typeid(T).name());
+            OrxVerify(T::singletonPtr_s == nullptr, "T=" << typeid(T).name());
             T::singletonPtr_s = static_cast<T*>(this);
         }
@@ -139,6 +139,6 @@
         virtual ~Singleton()
         {
-            OrxVerify(T::singletonPtr_s != NULL, "T=" << typeid(T).name());
-            T::singletonPtr_s = NULL;
+            OrxVerify(T::singletonPtr_s != nullptr, "T=" << typeid(T).name());
+            T::singletonPtr_s = nullptr;
         }
 
Index: code/branches/cpp11_v2/src/libraries/util/SmallObjectAllocator.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/SmallObjectAllocator.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/SmallObjectAllocator.cc	(revision 10765)
@@ -97,5 +97,5 @@
                 setNext(block + i * this->chunkSize_, block + (i + 1) * this->chunkSize_);
 
-            // the next_ pointer of the last chunk must point to NULL
+            // the next_ pointer of the last chunk must point to nullptr
             setNext(block + (this->numChunksPerBlock_ - 1) * this->chunkSize_, 0);
 

Index: code/branches/cpp11_v2/src/libraries/util/SignalHandler.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/SignalHandler.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/SignalHandler.cc	(revision 10765)
@@ -44,5 +44,5 @@
 namespace orxonox
 {
-    SignalHandler* SignalHandler::singletonPtr_s = NULL;
+    SignalHandler* SignalHandler::singletonPtr_s = nullptr;
 }
 
@@ -175,5 +175,5 @@
         dup2( gdbErr[1], STDERR_FILENO );
 
-        execlp( "sh", "sh", "-c", "gdb", static_cast<void*>(NULL));
+        execlp( "sh", "sh", "-c", "gdb", static_cast<void*>(nullptr));
       }
 
@@ -186,5 +186,5 @@
         perror("pipe failed!\n");
         kill( gdbPid, SIGTERM );
-        waitpid( gdbPid, NULL, 0 );
+        waitpid( gdbPid, nullptr, 0 );
         exit(EXIT_FAILURE);
       }
@@ -196,5 +196,5 @@
         perror("fork failed!\n");
         kill( gdbPid, SIGTERM );
-        waitpid( gdbPid, NULL, 0 );
+        waitpid( gdbPid, nullptr, 0 );
         exit(EXIT_FAILURE);
       }
@@ -297,6 +297,6 @@
 
 
-      waitpid( sigPid, NULL, 0 );
-      waitpid( gdbPid, NULL, 0 );
+      waitpid( sigPid, nullptr, 0 );
+      waitpid( gdbPid, nullptr, 0 );
 
       int wsRemoved = 0;
@@ -312,5 +312,5 @@
         bt.erase(0, 1);
 
-      time_t now = time(NULL);
+      time_t now = time(nullptr);
 
       std::string timeString =
@@ -388,5 +388,5 @@
     SignalHandler::SignalHandler()
     {
-        this->prevExceptionFilter_ = NULL;
+        this->prevExceptionFilter_ = nullptr;
     }
 
@@ -394,9 +394,9 @@
     SignalHandler::~SignalHandler()
     {
-        if (this->prevExceptionFilter_ != NULL)
+        if (this->prevExceptionFilter_ != nullptr)
         {
             // Remove the unhandled exception filter function
             SetUnhandledExceptionFilter(this->prevExceptionFilter_);
-            this->prevExceptionFilter_ = NULL;
+            this->prevExceptionFilter_ = nullptr;
         }
     }
@@ -408,7 +408,7 @@
 
         // don't register twice
-        assert(this->prevExceptionFilter_ == NULL);
-
-        if (this->prevExceptionFilter_ == NULL)
+        assert(this->prevExceptionFilter_ == nullptr);
+
+        if (this->prevExceptionFilter_ == nullptr)
         {
             // Install the unhandled exception filter function
@@ -441,5 +441,5 @@
             std::ofstream crashlog(SignalHandler::getInstance().filename_.c_str());
 
-            time_t now = time(NULL);
+            time_t now = time(nullptr);
 
             crashlog << "=======================================================" << endl;
@@ -480,5 +480,5 @@
     }
 
     /// Returns the stack trace for either the current function, or, if @a pExceptionInfo is not NULL, for the given exception context.
     /* static */ std::string SignalHandler::getStackTrace(PEXCEPTION_POINTERS pExceptionInfo)
     {
@@ -625,5 +625,5 @@
 #ifdef ORXONOX_COMPILER_GCC
                 int status;
-                char* demangled = __cxxabiv1::__cxa_demangle(symbol->Name, NULL, NULL, &status);
+                char* demangled = __cxxabiv1::__cxa_demangle(symbol->Name, nullptr, nullptr, &status);
                 if (demangled)
                 {
@@ -684,5 +684,5 @@
         HMODULE hModule;
 
-        std::string output = (GetModuleFileName(NULL, szModule, MAX_PATH) ? SignalHandler::getModuleName(szModule) : "Application");
+        std::string output = (GetModuleFileName(nullptr, szModule, MAX_PATH) ? SignalHandler::getModuleName(szModule) : "Application");
         output += " caused ";
 
@@ -480,5 +480,5 @@
     }
 
-    /// Returns the stack trace for either the current function, or, if @a pExceptionInfo is not NULL, for the given exception context.
+    /// Returns the stack trace for either the current function, or, if @a pExceptionInfo is not nullptr, for the given exception context.
     /* static */ std::string SignalHandler::getStackTrace(PEXCEPTION_POINTERS pExceptionInfo)
     {